@@ -1,12 +1,14 @@
+# -*- coding: utf-8 -*-
 require File.dirname(__FILE__) + '/../../spec_helper'
 
 describe Admin::ShopsController do
-  fixtures :authorities, :functions, :admin_users , :shops
+  fixtures :authorities, :functions, :admin_users , :shops, :retailers
   
   before(:each) do
-    session[:admin_user] = AdminUser.first
+    session[:admin_user] = admin_users(:load_by_admin_user_test_id_1)
     @controller.class.skip_before_filter @controller.class.before_filter
     @controller.class.skip_after_filter @controller.class.after_filter
+    @controller.class.before_filter :master_shop_check, :except => [:delivery_index, :delivery_new, :delivery_edit, :delivery_create, :delivery_update, :destroy, :sort]
   end
   
   #Delete this example and add some real ones
@@ -23,6 +25,12 @@ describe Admin::ShopsController do
       response.should be_success
       assigns[:shop].should == Shop.find(:first)
     end
+
+    it "マスターショップ以外はアクセスできない" do
+      session[:admin_user] = admin_users(:admin18_retailer_id_is_another_shop)
+      get 'index'
+      response.should redirect_to(:controller => "home", :action => "index")
+    end
   end
   
   describe "POST 'update'" do
@@ -64,8 +72,16 @@ describe Admin::ShopsController do
     it "should be successful" do
       get 'delivery_index'
       response.should be_success
-      assigns[:delivery_traders].should == DeliveryTrader.find(:all)
+      assigns[:delivery_traders].should == DeliveryTrader.find(:all, :conditions => ["retailer_id = ?", session[:admin_user].retailer_id], :order=>"position")
     end
+
+    it "他店舗では他店舗用の配送業者のみ表示" do
+      session[:admin_user] = admin_users(:admin18_retailer_id_is_another_shop)
+      get 'delivery_index'
+      response.should be_success
+      assigns[:delivery_traders].should == DeliveryTrader.find(:all, :conditions => ["retailer_id = ?", session[:admin_user].retailer_id], :order=>"position")
+    end
+
   end
   
   describe "GET 'sort'" do
@@ -76,6 +92,7 @@ describe Admin::ShopsController do
       get 'up', :model => "delivery_traders", :id => 2, :return_act=>"delivery_list"
       DeliveryTrader.find(2).position.should == 1
       response.should redirect_to(:action => "delivery_list")
+      DeliveryTrader.find(3).position.should == 1
     end
     
     it "positionを上げる場合(これ以上あがらない)" do
@@ -91,6 +108,7 @@ describe Admin::ShopsController do
       get 'down', :model => "delivery_traders", :id => 1, :return_act=>"delivery_list"
       DeliveryTrader.find(1).position.should == 2
       response.should redirect_to(:action => "delivery_list")
+      DeliveryTrader.find(3).position.should == 1
     end
     
     it "positionを下げる場合（これ以上下がらない）" do
@@ -105,7 +123,7 @@ describe Admin::ShopsController do
   describe "GET 'destroy'" do
     it "削除に成功する" do
       get 'destroy', :model => "delivery_traders", :id => 1,:return_act=>"delivery_list"
-      DeliveryTrader.find(:first).id.should == 2
+      DeliveryTrader.find(:first, :order=>"id").id.should == 2
       response.should redirect_to(:action => "delivery_list")
     end
     it "削除に失敗する場合" do
@@ -150,8 +168,9 @@ describe Admin::ShopsController do
   end
   
   describe "GET 'delivery_create'" do
+    fixtures :delivery_traders,:delivery_times,:delivery_fees
     before do
-      @delivery_trader = {:name=>"追加",:url=>"http://www.hoge.com"}
+      @delivery_trader = {:name=>"追加",:url=>"http://www.hoge.com", :retailer_id => Retailer::DEFAULT_ID}
       @delivery_time = {}
       DeliveryTime::MAX_SIZE.times do |i|
         @delivery_time["#{i}"]={:name=>"午前中なら#{i}"}
@@ -186,6 +205,29 @@ describe Admin::ShopsController do
       DeliveryTrader.find(:first,:order=>"id desc",:limit=>1).delivery_fees.size.should == DeliveryFee::MAX_SIZE
       DeliveryTrader.find(:first,:order=>"id desc",:limit=>1).delivery_fees[47].prefecture_id == nil
     end
+
+    it "retailer_idが無効なものは登録できない" do
+      delivery_trader = {:name=>"追加",:url=>"http://www.hoge.com", :retailer_id => nil}
+      trader_count = DeliveryTrader.count
+      time_count = DeliveryTime.count
+      fee_count = DeliveryFee.count
+      get 'delivery_create', :delivery_trader=>delivery_trader,:delivery_time=>@delivery_time,:delivery_fee=>@delivery_fee
+      response.should render_template("admin/shops/delivery_new.html.erb")
+    end
+
+    it "存在しないretailer_idは登録できない" do
+      retailer_max = Retailer.find(:last).id + 100
+      delivery_trader = @delivery_trader.merge({:name => "fail_trader", :retailer_id => retailer_max})
+      get 'delivery_create', :delivery_trader=>delivery_trader,:delivery_time=>@delivery_time,:delivery_fee=>@delivery_fee
+      response.should render_template("admin/shops/delivery_new.html.erb")
+    end
+
+    it "同じ名前でもretailer_idが異なれば登録できる" do 
+      other_shop = delivery_traders(:other_shop)
+      delivery_trader = @delivery_trader.merge({:name => other_shop.name })
+      get 'delivery_create', :delivery_trader=>delivery_trader,:delivery_time=>@delivery_time,:delivery_fee=>@delivery_fee
+      response.should redirect_to(:action=>:delivery_index)
+    end
   end
   
   
@@ -301,7 +343,7 @@ describe Admin::ShopsController do
   
   describe "GET 'payment_create'" do
     before do
-      @record = {:name => "追加", :fee => 1, :delivery_trader_id => 1}
+      @record = {:name => "追加", :fee => 1}
     end
     
     it "新規作成" do
